summaryrefslogtreecommitdiffhomepage
path: root/dev/Kernel/KernelKit/UserProcessScheduler.h
diff options
context:
space:
mode:
Diffstat (limited to 'dev/Kernel/KernelKit/UserProcessScheduler.h')
-rw-r--r--dev/Kernel/KernelKit/UserProcessScheduler.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/dev/Kernel/KernelKit/UserProcessScheduler.h b/dev/Kernel/KernelKit/UserProcessScheduler.h
index a1fbde5b..987cfb3f 100644
--- a/dev/Kernel/KernelKit/UserProcessScheduler.h
+++ b/dev/Kernel/KernelKit/UserProcessScheduler.h
@@ -1,6 +1,6 @@
/* -------------------------------------------
- Copyright (C) 2024, t& Corporation, all rights reserved.
+ Copyright (C) 2024, t& Labs, all rights reserved.
------------------------------------------- */
@@ -31,7 +31,7 @@ namespace Kernel
//! @note Forward class declarations.
class IDylibObject;
- class UserThread;
+ class UserProcess;
class UserProcessTeam;
class UserProcessScheduler;
class UserProcessHelper;
@@ -142,16 +142,16 @@ namespace Kernel
}
};
- /// @name UserThread
+ /// @name UserProcess
/// @brief User process class, holds information about the running process/thread.
- class UserThread final
+ class UserProcess final
{
public:
- explicit UserThread();
- ~UserThread();
+ explicit UserProcess();
+ ~UserProcess();
public:
- ZKA_COPY_DEFAULT(UserThread);
+ ZKA_COPY_DEFAULT(UserProcess);
public:
Char Name[kProcessNameLen] = {"Process"};
@@ -261,20 +261,20 @@ namespace Kernel
ZKA_COPY_DEFAULT(UserProcessTeam);
- Array<UserThread, kSchedProcessLimitPerTeam>& AsArray();
- Ref<UserThread>& AsRef();
+ Array<UserProcess, kSchedProcessLimitPerTeam>& AsArray();
+ Ref<UserProcess>& AsRef();
ProcessID& Id() noexcept;
public:
- Array<UserThread, kSchedProcessLimitPerTeam> mProcessList;
- Ref<UserThread> mCurrentProcess;
+ Array<UserProcess, kSchedProcessLimitPerTeam> mProcessList;
+ Ref<UserProcess> mCurrentProcess;
ProcessID mTeamId{0};
ProcessID mProcessCount{0};
};
- typedef Array<UserThread, kSchedProcessLimitPerTeam> UserThreadArray;
+ typedef Array<UserProcess, kSchedProcessLimitPerTeam> UserThreadArray;
- using UserProcessRef = UserThread&;
+ using UserProcessRef = UserProcess&;
/// @brief Process scheduler class.
/// The main class which you call to schedule user processes.
@@ -303,7 +303,7 @@ namespace Kernel
const Bool HasMP() override;
public:
- Ref<UserThread>& GetCurrentProcess();
+ Ref<UserProcess>& GetCurrentProcess();
const SizeT Run() noexcept;
public:
@@ -314,14 +314,14 @@ namespace Kernel
};
/*
* \brief UserThread helper class, which contains needed utilities for the scheduler.
*/
class UserProcessHelper final
{
public:
STATIC Bool Switch(VoidPtr image_ptr, UInt8* stack_ptr, HAL::StackFramePtr frame_ptr, const PID& new_pid);
- STATIC Bool CanBeScheduled(const UserThread& process);
+ STATIC Bool CanBeScheduled(const UserProcess& process);
STATIC ErrorOr<PID> TheCurrentPID();
STATIC SizeT StartScheduling();
};
@@ -314,14 +314,14 @@ namespace Kernel
};
/*
- * \brief UserThread helper class, which contains needed utilities for the scheduler.
+ * \brief UserProcess helper class, which contains needed utilities for the scheduler.
*/
class UserProcessHelper final